#include <stdio.h>
#include <stdlib.h>
#include "CSDL.h"

CSDL sdl;

void CSDL::printError(const char* funct)
{
    printf("Error in %s : %s\n", funct, SDL_GetError());
    exit(EXIT_FAILURE);
}

void CSDL::Init(Uint32 flags)
{
    if (SDL_Init(flags) != 0)
        printError("CSDL::Init");
}

SDL_Window* CSDL::CreateWindow(const char* title, int x, int y, int w, int h, Uint32 flags)
{
    SDL_Window* pWindow = NULL;
    pWindow = SDL_CreateWindow(title, x, y, w, h, flags);

    if (pWindow == NULL)
        printError("CSDL::CreateWindow");

    return pWindow;
}

void CSDL::DestroyWindow(SDL_Window* win)
{
    SDL_DestroyWindow(win);
}

SDL_Renderer* CSDL::CreateRenderer(SDL_Window* window, int index, Uint32 flags)
{
    SDL_Renderer* renderer = SDL_CreateRenderer(window, index, flags);

    if (renderer == NULL)
        printError("CSDL::CreateRenderer");

    return renderer;
}

void CSDL::DestroyRenderer(SDL_Renderer* renderer)
{
    SDL_DestroyRenderer(renderer);
}

void CSDL::Quit()
{
    SDL_Quit();
}

void CSDL::Delay(Uint32 ms)
{
    SDL_Delay(ms);
}

int CSDL::PollEvent(SDL_Event* event)
{
    return SDL_PollEvent(event);
}

void CSDL::SetRenderDrawColor(SDL_Renderer* renderer, Uint8 r, Uint8 g, Uint8 b, Uint8 a)
{
    if (SDL_SetRenderDrawColor(renderer, r, g, b, a) != 0)
        printError("CSDL::SetRenderDrawColor");
}

void CSDL::RenderClear(SDL_Renderer* renderer)
{
    if (SDL_RenderClear(renderer) != 0)
        printError("CSDL::RenderClear");
}

void CSDL::RenderPresent(SDL_Renderer* renderer)
{
    SDL_RenderPresent(renderer);
}

SDL_Texture* CSDL::CreateTexture(SDL_Renderer* renderer, Uint32 format, int access, int w, int h)
{
    SDL_Texture* texture = SDL_CreateTexture(renderer, format, access, w, h);

    if (texture == NULL)
        printError("CSDL::CreateTexture");

    return texture;
}

void CSDL::UpdateTexture(SDL_Texture* texture, const SDL_Rect* rect, const void* pixels, int pitch)
{
    if (SDL_UpdateTexture(texture, rect, pixels, pitch) != 0)
        printError("CSDL::UpdateTexture");
}

void CSDL::DestroyTexture(SDL_Texture* texture)
{
    SDL_DestroyTexture(texture);
}

void CSDL::RenderCopy(SDL_Renderer* renderer, SDL_Texture* texture, const SDL_Rect* srcrect, const SDL_Rect* dstrect)
{
    if (SDL_RenderCopy(renderer, texture, srcrect, dstrect) != 0)
        printError("CSDL::RenderCopy");
}

Uint64 CSDL::GetPerformanceCounter()
{
    return SDL_GetPerformanceCounter();
}

Uint64 CSDL::GetPerformanceFrequency()
{
    return SDL_GetPerformanceFrequency();
}
